@@ -1,4 +1,4 @@
-/*	$Id: FaxFont.h,v 1.2 2007/11/24 00:45:47 faxguy Exp $ */
+/*	$Id$ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -46,7 +46,7 @@ public:
     u_int	fontHeight() const;
     virtual u_int charWidth(u_int) const = 0;
     virtual void strWidth(const char* text, u_int& w, u_int& h) const = 0;
-    virtual u_int imageText(const char* text, bool isutf8, 
+    virtual u_int imageText(const char* text,
 		    u_short* bitmap, u_int w, u_int h,
 		    u_int lm, u_int rm, u_int tm, u_int bm) const = 0;
     virtual void print(FILE*) const = 0;
