@@ -1,4 +1,4 @@
-/*	$Id: Job.h,v 1.5 2007/04/06 22:46:40 faxguy Exp $ */
+/*	$Id$ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -35,6 +35,7 @@
 #include "Str.h"
 
 typedef unsigned int JobStatus;
+class Batch;
 class Modem;
 class Job;
 class FaxRequest;
@@ -60,21 +61,23 @@ public:
     ~JobTTSHandler();
     void timerExpired(long, long);
 };
-class JobPrepareHandler : public IOHandler {
+
+
+/*
+ * This does sligltly more than the other PID handlers.
+ * It also collects on a fd and stores it for JobControl.
+ */
+class JobCtrlHandler : public IOHandler {
 private:
     Job& job;
+    fxStr buf;
+    int fd;
 public:
-    JobPrepareHandler(Job&);
-    ~JobPrepareHandler();
-    void childStatus(pid_t, int);
-};
-class JobSendHandler : public IOHandler {
-private:
-    Job& job;
-public:
-    JobSendHandler(Job&);
-    ~JobSendHandler();
+    JobCtrlHandler(Job&);
+    ~JobCtrlHandler();
+    int inputReady (int fd);
     void childStatus(pid_t, int);
+    friend class Job;
 };
 
 fxDECLARE_StrKeyDictionary(JobDict, Job*)
@@ -86,8 +89,7 @@ class Job : public QLink {
 private:
     JobKillHandler	killHandler;	// Dispatcher handler for kill timeout
     JobTTSHandler	ttsHandler;	// Dispatcher handler for tts timeout
-    JobPrepareHandler	prepareHandler;	// Dispatcher handler for job prep work
-    JobSendHandler	sendHandler;	// Dispatcher handler for job send work
+    JobCtrlHandler	ctrlHandler;	// Dispatcher handler for job control work
 
     static JobDict registry;
     static JobControlInfo defJCI;
@@ -126,25 +128,20 @@ public:
     fxStr	dest;		// canonical destination identity
     fxStr	device;		// modem to be used
     fxStr	commid;		// commid of last call
-    Job*	dnext;		// linked list by destination
     Modem*	modem;		// modem/server currently assigned to job
     QLink	triggers;	// waiting specifically on this job
-    TimeOfDay	tod;		// time of day restrictions
 
-    Job*	bprev;		// prev in batch
-    Job*	bnext;		// next in batch
-    FaxRequest*	breq;		// pointer to request used by batching support
     JobControlInfo* jci;	// Job control information
 
     Job(const FaxRequest&);
     void update(const FaxRequest& req);
     ~Job();
 
-    void remove(void);
-
     static Job* getJobByID(const fxStr& jobid);
     static fxStr jobStatusName(const JobStatus);
 
+    bool higherPriority(const Job& other) const;
+
     void startKillTimer(long sec);
     void stopKillTimer();
 
@@ -157,8 +154,6 @@ public:
 
     void encode(fxStackBuffer&) const;	// encode in JobExt format
 
-    Job* bfirst();			// first job in batch
-
     const JobControlInfo& getJCI (void) const;
 };
 
