@@ -1,4 +1,4 @@
-/*	$Id: JobControl.h 1155 2013-04-26 22:39:33Z faxguy $ */
+/*	$Id$ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -50,24 +50,11 @@ private:
     u_int	maxTries;		// max transmit attempts
     fxStr	rejectNotice;		// if set, reject w/ this notice
     fxStr	modem;			// if set, try with it
-    fxStr	proxy;			// if set, proxy-send job there
-    fxStr	proxyuser;		// if set, use this as the login username
-    fxStr	proxypass;		// if set, use this as the login password
-    fxStr	proxymailbox;		// if set, use this as the identity
-    fxStr	proxynotification;	// if set, use this as the notification
-    fxStr	proxyjobtag;		// if set, use this as the jobtag
-    mode_t	proxylogmode;		// mode for logs retrieved from proxy
-    int		proxytries;		// if set, specify the number of tries
-    int		proxydials;		// if set, specify the number of dials
-    int		proxyreconnects;	// the number of reconnections to make for any job
     TimeOfDay	tod;			// time of day restrictions
     int		usexvres;		// use extended resolution
-    int		usecolor;		// use color
-    u_int	vres;			// use specified resolution
+    u_int	vres;			// use extended resolution
     fxStr	args;			// arguments for subprocesses
-    int		priority;		// override submission priority with this
     int		desireddf;		// if set, desireddf value
-    int		notify;			// if set, notify value
 
     // default returned on no match
     static const JobControlInfo defControlInfo;
@@ -79,36 +66,26 @@ public:
     JobControlInfo(const JobControlInfo& other);
     ~JobControlInfo();
 
+
+    bool isCompatible (const JobControlInfo& other) const;
+
+    void parseEntry(const char* tag, const char* value, bool quoted);
+
     u_int getMaxConcurrentCalls() const;
     u_int getMaxSendPages() const;
     u_int getMaxDials() const;
     u_int getMaxTries() const;
     const fxStr& getRejectNotice() const;
     const fxStr& getModem() const;
-    const fxStr& getProxy() const;
-    const fxStr& getProxyUser() const;
-    const fxStr& getProxyPass() const;
-    const fxStr& getProxyMailbox() const;
-    const fxStr& getProxyNotification() const;
-    const fxStr& getProxyJobTag() const;
-    const mode_t getProxyLogMode() const;
-    int getProxyTries() const;
-    int getProxyDials() const;
-    int getProxyReconnects() const;
     time_t nextTimeToSend(time_t) const;
     int getUseXVRes() const;
-    int getUseColor() const;
     u_int getVRes() const;
-    int getPriority() const;
     int getDesiredDF() const;
-    int getNotify() const;
-    bool isNotify(u_int what) const;
     const fxStr& getArgs() const;
 
     virtual bool setConfigItem(const char*, const char*);
     virtual void configError(const char*, ...);
     virtual void configTrace(const char*, ...);
 };
-inline const fxStr& JobControlInfo::getArgs() const	{ return args; }
 
 #endif /* _JobControl_ */
