@@ -1,4 +1,4 @@
-/*	$Id: Modem.h 872 2008-09-14 10:33:17Z faxguy $ */
+/*	$Id$ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -75,8 +75,7 @@ public:
     enum {
 	DOWN  = 0,		// modem identified, but offline
 	READY = 1,		// modem ready for use
-	BUSY  = 2,		// modem in use
-	EXEMPT = 3		// modem exempt from sending use
+	BUSY  = 2		// modem in use
     };
 private:
     int		fd;		// cached open FIFO file
@@ -94,6 +93,7 @@ private:
     ModemLockWaitHandler lockHandler;
 
     static QLink list;		// list of all modems
+    static int modemsReady;	// count of ready modems
 
     void setCapabilities(const char*);	// specify modem capabilities
     void setNumber(const char*);	// specify modem phone number
@@ -108,12 +108,13 @@ public:
 
     static void CLEANUP (void);
 
+    static bool anyReady (void);
     static Modem& getModemByID(const fxStr& id);
-    static Modem* modemExists(const fxStr& id, bool notexempt = false);
-    static Modem* findModem(const Job& job, bool ignorebusy);
+    static Modem* modemExists(const fxStr& id);
+    static Modem* findModem(const Job& job);
     bool isInGroup(const fxStr& mgroup);
 
-    bool assign(Job&, bool ignorebusy);	// assign modem
+    bool assign();			// assign modem
     void release();			// release modem
 
     void startLockPolling(long sec);	// initiate polling thread
@@ -153,6 +154,8 @@ inline const Class2Params& Modem::getCapabilities() const { return caps; }
 inline u_int Modem::getPriority() const		{ return priority; }
 inline const fxStr& Modem::getCommID() const	{ return commid; }
 
+inline bool Modem::anyReady()			{ return modemsReady > 0; }
+
 /*
  * Modem iterator class; for iterating
  * over the set of known modems.
