@@ -1,4 +1,4 @@
-/*	$Id: MIMEState.h 1032 2010-11-23 03:04:23Z faxguy $ */
+/*	$Id$ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -41,7 +41,6 @@ enum Encoding {			// content-transfer-encoding
 
 enum Charset {			// charset
     CS_USASCII,			// us-ascii
-    CS_UTF8,			// utf-8
     CS_ISO8859_1,		// iso-8859-1
     CS_ISO8859_2,		// iso-8859-2
     CS_ISO8859_3,		// iso-8859-3
@@ -63,7 +62,6 @@ private:
     fxStr	subtype;		// content subtype
     fxStr	desc;			// content description
     fxStr	cid;			// content ID
-    fxStr	disp;			// content disposition
     fxStr	boundary;		// multipart boundary marker
     u_int	blen;			// adjusted boundary length
     bool	lastPart;		// true if last multipart boundary seen
@@ -86,7 +84,6 @@ public:
     virtual ~MIMEState();
 
     u_int	lineno;			// input line number
-    bool	external;		// true if part was formatted externally
     bool parse(const MsgFmt&, fxStr& emsg);
 
     const fxStr& getType(void) const;
@@ -95,7 +92,6 @@ public:
     bool isParent(const char* type, const char* subtype) const;
     const fxStr& getDescription(void) const;
     const fxStr& getContentID(void) const;
-    const fxStr& getDisposition(void) const;
 
     virtual void setEncoding(const char*);
     Encoding getEncoding(void) const;
@@ -121,5 +117,4 @@ inline const fxStr& MIMEState::getType(void) const	{ return type; }
 inline const fxStr& MIMEState::getSubType(void) const	{ return subtype; }
 inline const fxStr& MIMEState::getDescription(void) const { return desc; }
 inline const fxStr& MIMEState::getContentID(void) const	{ return cid; }
-inline const fxStr& MIMEState::getDisposition(void) const { return disp; }
 #endif /* _MIMEState_ */
